pub trait Meter<K, V> {
type Measure: Default + Copy;
// Required method
fn measure<Q: ?Sized>(&self, key: &Q, value: &V) -> Self::Measure
where K: Borrow<Q>;
}Expand description
A trait for measuring the size of a cache entry.
If you implement this trait, you should use usize as the Measure type, otherwise you will
also have to implement CountableMeter.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.